==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/DeleteSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.Delete;
import io.ciera.tool.sql.ooaofooa.instanceaccess.DeleteSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class DeleteSetImpl extends InstanceSet<DeleteSet,Delete> implements DeleteSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( Delete delete : this ) delete.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( Delete delete : this ) delete.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( Delete delete : this ) act_smtset.add( delete.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R634_destroys_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Delete delete : this ) v_varset.add( delete.R634_destroys_V_VAR() );
        return v_varset;
    }


    @Override
    public Delete nullElement() {
        return DeleteImpl.EMPTY_DELETE;
    }

    @Override
    public DeleteSet emptySet() {
      return new DeleteSetImpl();
    }

    @Override
    public DeleteSet value() {
        return this;
    }

    @Override
    public List<Delete> elements() {
        return Arrays.asList(toArray(new Delete[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/DeleteSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.Delete;
import io.ciera.tool.sql.ooaofooa.instanceaccess.DeleteSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class DeleteSetImpl extends InstanceSet<DeleteSet,Delete> implements DeleteSet {

    public DeleteSetImpl() {
    }

    public DeleteSetImpl(Comparator<? super Delete> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( Delete delete : this ) delete.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( Delete delete : this ) delete.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( Delete delete : this ) act_smtset.add( delete.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R634_destroys_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Delete delete : this ) v_varset.add( delete.R634_destroys_V_VAR() );
        return v_varset;
    }


    @Override
    public Delete nullElement() {
        return DeleteImpl.EMPTY_DELETE;
    }

    @Override
    public DeleteSet emptySet() {
      return new DeleteSetImpl();
    }

    @Override
    public DeleteSet emptySet(Comparator<? super Delete> comp) {
      return new DeleteSetImpl(comp);
    }

    @Override
    public DeleteSet value() {
        return this;
    }

    @Override
    public List<Delete> elements() {
        return Arrays.asList(toArray(new Delete[0]));
    }

}
